@@ -582,6 +582,10 @@ class Client(object):
 
         return self.login('/v1/auth/{0}/login'.format(mount_point), json=params, use_token=use_token)
 
+    @utils.deprecated_method(
+        to_be_removed_in_version='0.13.0',
+        new_method=api.auth_methods.Cert.login,
+    )
     def auth_tls(self, mount_point='cert', use_token=True):
         """POST /auth/<mount point>/login
 
@@ -592,7 +596,7 @@ class Client(object):
         :return:
         :rtype:
         """
-        return self.login('/v1/auth/{0}/login'.format(mount_point), use_token=use_token)
+        return self.auth.cert.login(mount_point=mount_point, use_token=use_token)
 
     def auth_userpass(self, username, password, mount_point='userpass', use_token=True, **kwargs):
         """POST /auth/<mount point>/login/<username>
@@ -1623,7 +1627,7 @@ class Client(object):
         return self._adapter.get(url)
 
     def create_kubernetes_role(self, name, bound_service_account_names, bound_service_account_namespaces, ttl="",
-                               max_ttl="", period="", policies=None, mount_point='kubernetes'):
+                               max_ttl="", period="", policies=None, token_type="", mount_point='kubernetes'):
         """POST /auth/<mount_point>/role/:name
 
         :param name: Name of the role.
@@ -1646,6 +1650,7 @@ class Client(object):
         :type policies: list.
         :param mount_point: The "path" the k8s auth backend was mounted on. Vault currently defaults to "kubernetes".
         :type mount_point: str.
+        :type token_type: str.
         :return: Will be an empty body with a 204 status code upon success
         :rtype: requests.Response.
         """
@@ -1661,6 +1666,9 @@ class Client(object):
             'period': period,
             'policies': policies,
         }
+        if token_type:
+            params['token_type'] = token_type
+        
         url = 'v1/auth/{0}/role/{1}'.format(mount_point, name)
         return self._adapter.post(url, json=params)
 
